#!/usr/bin/env bash

bold=$(tput bold)      # ${bold}
normal=$(tput sgr0)    # ${normal}
yellow=$(tput setaf 3) # ${yellow}

# Zenity ablak megjelenítése
user_choice=$(zenity --list --radiolist --width='650' --height='370' \
  --title="Válaszd ki a nyelvet és a GPU-t!" \
  --text="Válassz az alábbi opciók közül:" \
  --column="Válassz" --column="GPU - Rendszer nyelv" \
   FALSE "English Language"  \
   FALSE "Magyar Nyelv")
if [[ $? -eq 1 ]]; then
   echo ${bold}${yellow}A script futása leállítva. Kilépés!${normal}
   exit 1
fi


# Nala telepítés
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}NALA - DEB Pkg${normal}
  echo
    sudo apt update
    sudo apt install nala -y
    sudo apt purge ubuntu-advantage-tools -y
    sudo sed -i 's/.set.enabled=true/.set.enabled=false/' /var/lib/NetworkManager/NetworkManager-intern.conf
  echo
  echo ${bold}${yellow}NALA - DEB Pkg ${normal}installed.
  echo ---------------------------------------------

# Adding Custom rave command
echo ---------------------------------------------
  echo Installing ${bold}${yellow}rave command.${normal}
  echo
    sudo cp -a rave /usr/local/bin/
    sudo chmod +x /usr/local/bin/rave
    sudo cp -a rave-comp.sh /etc/bash_completion.d/
    sudo chmod +x /etc/bash_completion.d/rave-comp.sh
  echo
  echo ${bold}${yellow}Rave command with bash completion ${normal}installed.
  echo ---------------------------------------------

# Installing GNOME Software
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}GNOME Software and Flatpak Plugin - DEB Pkg${normal}
  echo
    sudo nala remove pop-shop* -y
    sudo apt install gnome-software gnome-software-plugin-flatpak -y
  echo
  echo ${bold}${yellow}GNOME Software and Flatpak Plugin ${normal}installed.
  echo ---------------------------------------------

  # Installing Custom Rave Wallpapers made by DanyHolder & Pacuka
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Custom Rave Wallpapers${normal}
  echo
    sudo rm -rf /usr/share/backgrounds/pop
    sudo mkdir -p /usr/share/backgrounds/pop
    sudo tar -xvf RP_Wallpapers.tar.xz -C /usr/share/backgrounds/pop/
    sudo cp -a rave-Wallpapers.xml /usr/share/gnome-background-properties/
  echo
  echo ${bold}${yellow}Custom Rave Wallpapers ${normal}installed.
  echo ---------------------------------------------

# Yaru Theme
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Yaru theme - DEB Pkg${normal}
  echo
    sudo apt install yaru-theme-* -y
  echo
  echo ${bold}${yellow}Yaru theme ${normal}installed.
  echo ---------------------------------------------

# Setting Yaru Dark Black Theme
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Setting correct Rave Theme${normal}
  echo
    gsettings set org.gnome.desktop.interface gtk-theme 'Yaru-purple-dark'
    gsettings set org.gnome.desktop.interface cursor-theme 'Yaru'
    gsettings set org.gnome.desktop.interface icon-theme 'Yaru-purple-dark'
    gsettings set org.gnome.desktop.sound theme-name 'Yaru'
  echo
  echo ${bold}${yellow}Correct Rave Theme ${normal}set.
  echo ---------------------------------------------

# Gsettings changes
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Setting UI Preferences before DCONF${normal}
  echo
    gsettings set org.gnome.desktop.screensaver lock-enabled false
    gsettings set org.gnome.desktop.session idle-delay 0
    gsettings set org.gnome.desktop.wm.preferences button-layout ":minimize,maximize,close"
    gsettings set org.gnome.mutter center-new-windows true
  echo
  echo ${bold}${yellow}UI Preferences before DCONF ${normal}set.
  echo ---------------------------------------------

# Disabling Geoclue
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Geoclue service disabling / masking${normal}
  echo
    sudo systemctl disable geoclue.service
    sudo systemctl mask geoclue.service
  echo
  echo ${bold}${yellow}Geoclue service disabling / masking ${normal}finished.
  echo ---------------------------------------------

# Enable x86
  echo ---------------------------------------------
  echo Enabling ${bold}${yellow}x86 architecture${normal}
  echo
     sudo dpkg --add-architecture i386
  echo
  echo ${bold}${yellow}x86 architecture ${normal}enabled.
  echo ---------------------------------------------

# Dependencies
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Dependencies${normal}
  echo
    sudo nala install lm-sensors ffmpeg -y
  echo
  echo ${bold}${yellow}Dependencies ${normal}installed.
  echo ---------------------------------------------

# Xanmod Kernel
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}XanMod - Gaming Kernel AMD - DEB Pkg${normal}

  wget -qO - https://dl.xanmod.org/archive.key | sudo gpg --dearmor -o /usr/share/keyrings/xanmod-archive-keyring.gpg
  echo 'deb [signed-by=/usr/share/keyrings/xanmod-archive-keyring.gpg] http://deb.xanmod.org releases main' | sudo tee /etc/apt/sources.list.d/xanmod-release.list
  sudo apt update && sudo apt install linux-xanmod-edge-x64v4 -y

  echo ${bold}${yellow}XanMod - Gaming Kernel AMD ${normal}installed.
  echo ---------------------------------------------

# Flatseal - Flatpak app jogosultság beállító
echo
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Flatseal - flatpak${normal}

  flatpak install flathub com.github.tchx84.Flatseal --user -y
  sudo cp -a overrides /home/$USER/.local/share/flatpak

  echo ${bold}${yellow}Flatseal ${normal}installed.
  echo ---------------------------------------------
  echo

# All Updates
  echo ---------------------------------------------
  echo ${bold}${yellow}Upgrading the System${normal}
  echo
    sudo nala upgrade -y
  echo
  echo ${bold}${yellow}System upgraded!${normal}
  echo ---------------------------------------------

fwupdmgr update -y

# User beállítások 
  echo
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}User settings${normal}

  sudo rsync -ap --info=progress2 raveos-bg.png /usr/share/backgrounds/
  sudo rsync -ap --info=progress2 gnome-shell /home/$USER/.local/share/
  sudo rsync -ap --info=progress2 burn-my-windows /home/$USER/.config/
  sudo apt install git -y
  git clone --depth=1 https://github.com/realmazharhussain/gdm-tools.git
  sudo rsync -ap --info=progress2 install.sh gdm-settings/
  cd gdm-tools
  ./install.sh
  cd -
  set-gdm-theme set Yaru-purple-dark /usr/share/backgrounds/raveos-bg.png
  dconf load / < raveui-*
  sudo apt update
  sudo apt upgrade -y
  sudo rm -rf gdm-tools
  # Debloater Script by DanyHolder
  sudo nala purge gnome-contacts* pop-shop* gnome-remote-desktop* gucharmap* com.github.donadigo.eddy* totem* geary* seahorse* popsicle* libreoffice-draw* libreoffice-math* libreoffice-impress* imagemagick* vinagre* gnome-font-viewer gnome-power-manager -y

  echo ${bold}${yellow}User settings ${normal}installed.
  echo ---------------------------------------------
  
  echo
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Gnome Extension Manager - DEB Pkg${normal}

      sudo apt install gnome-shell-extensions -y

  echo ${bold}${yellow}Gnome Extension Manager / All Gnome Extensions ${normal}installed.
  echo ---------------------------------------------
  
  dconf load / < raveui*

  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Librewolf - DEB Pkg${normal}

  sudo apt update && sudo apt install -y wget gnupg lsb-release apt-transport-https ca-certificates

  distro=$(if echo " una bookworm vanessa focal jammy bullseye vera uma " | grep -q " $(lsb_release -sc) "; then lsb_release -sc; else echo focal; fi)

  wget -O- https://deb.librewolf.net/keyring.gpg | sudo gpg --dearmor -o /usr/share/keyrings/librewolf.gpg
  sudo tee /etc/apt/sources.list.d/librewolf.sources << EOF > /dev/null
Types: deb
URIs: https://deb.librewolf.net
Suites: $distro
Components: main
Architectures: amd64
Signed-By: /usr/share/keyrings/librewolf.gpg
EOF
  sudo apt update
  sudo nala install librewolf -y
  sudo cp -a .librewolf /home/$USER/

  echo ${bold}${yellow}LibreWolf ${normal}installed.
  echo ---------------------------------------------

  echo ---------------------------------------------
  echo Installing ${bold}${yellow}VLC Media Player - flatpak${normal}

  flatpak install flathub org.videolan.VLC --user -y

  echo ${bold}${yellow}VLC Media Player ${normal}installed.
  echo ---------------------------------------------

  echo ---------------------------------------------
  echo Installing ${bold}${yellow}QBittorrent - flatpak${normal}

  flatpak install flathub org.qbittorrent.qBittorrent --user -y

  echo ${bold}${yellow}QBittorrent ${normal}installed.
  echo ---------------------------------------------
  
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}FreeTube - flatpak${normal}

  flatpak install flathub io.freetubeapp.FreeTube --user -y

  echo ${bold}${yellow}FreeTube ${normal}installed.
  echo ---------------------------------------------

  if [[ $user_choice = *"English Language"* ]]; then
  
  # Wayland Auto-Enable
  echo
  echo ---------------------------------------------
  echo Enabling ${bold}${yellow}Wayland Window Manager${normal}
  echo
    sudo cp -a rave-pp.png /usr/share/pixmaps/faces/
    sudo sed -i 's/WaylandEnable=false/WaylandEnable=true/' /etc/gdm3/custom.conf
    sudo sed -i '5d' /var/lib/AccountsService/users/$USER
    sudo sed -i '5 i Icon=/usr/share/pixmaps/faces/rave-pp.png' /var/lib/AccountsService/users/$USER
    echo 'Session=pop-wayland' | sudo tee -a /var/lib/AccountsService/users/$USER
    sudo cp -a .themes /home/$USER/
    sudo cp -a .icons /home/$USER/
    sudo cp -a .mozilla /home/$USER/
    dconf load / < raveui-eng
  echo
  echo ${bold}${yellow}Wayland Window Manager ${normal}enabled.
  echo ---------------------------------------------
  echo

  if [[ $user_choice = *"Magyar Nyelv"* ]]; then
  
  # Wayland Auto-Enable
  echo
  echo ---------------------------------------------
  echo Enabling ${bold}${yellow}Wayland Window Manager${normal}
  echo
    sudo cp -a rave-pp.png /usr/share/pixmaps/faces/
    sudo sed -i 's/WaylandEnable=false/WaylandEnable=true/' /etc/gdm3/custom.conf
    sudo sed -i '5d' /var/lib/AccountsService/users/$USER
    sudo sed -i '5 i Icon=/usr/share/pixmaps/faces/rave-pp.png' /var/lib/AccountsService/users/$USER
    echo 'Session=pop-wayland' | sudo tee -a /var/lib/AccountsService/users/$USER
    sudo cp -a .themes /home/$USER/
    sudo cp -a .icons /home/$USER/
    sudo cp -a .mozilla /home/$USER/
    dconf load / < raveui-hun
  echo
  echo ${bold}${yellow}Wayland Window Manager ${normal}enabled.
  echo ---------------------------------------------
  echo

  echo
  echo ---------------------------------------------
  echo Downloading ${bold}${yellow}Hungarian LangPack${normal}
  echo
    sudo apt install language-pack-gnome-hu language-pack-gnome-hu-base language-pack-hu language-pack-hu-base -y
  echo
  echo ${bold}${yellow}Hungarian LangPack ${normal}downloaded.
  echo ---------------------------------------------

fi


# Script end

echo ${bold}${yellow}The system will restart in 3 seconds...${normal}
echo ${bold}${yellow}3...${normal}
sleep 1
echo ${bold}${yellow}2...${normal}
sleep 1
echo ${bold}${yellow}1...${normal}
sleep 1

sudo reboot
